Task: SuperGLUE
===============
Description: SuperGLUE (https://super.gluebenchmark.com/) is a new benchmark styled after GLUE with a new set of more difficult language understanding tasks, improved resources, and a new public leaderboard. This task uses the `AbstractHuggingFaceTeacher` to load the dataset.

Websites: https://huggingface.co/datasets/super_glue and https://super.gluebenchmark.com/
